elipdotter::index

Struct Simple

source
pub struct Simple { /* private fields */ }

Implementations

source

impl Simple

source

pub fn new( proximity_threshold: f32, proximity_algorithm: Algorithm, word_count_limit: usize, ) -> Self

proximity_threshold is the threshold where alike words are also accepted. It uses the range [0..1], where values nearer 0 allow more words. The default is 0.9.

proximity_threshold is the algorithm used for proximity checking of words.

word_count_limit is the number of words in this index where only words with the first character is used for approximate matching. Default is 2_500.

source

pub fn ingest(&mut self, other: Self)

Merges other with self.